@@ -23,14 +23,11 @@ class Project(Behance):
         _url = "%s?api_key=%s" % (_url, self.auth_key)
         #Call the API
         _results = self._get_api_data(_url)['project']
-
-        #Parse the data
-        for k, v in _results.items():
-            self._add_property(k, v)
+        self.set_data(_results)
 
     def get_comments(self):
         """Returns comments for a project as an attribute. If called more than
         once, will store the value to prevent repeatedly calling the API."""
         _url = url_join(self.base_url, str(self.project_id), 'comments')
         _url = "%s?api_key=%s" % (_url, self.auth_key)
-        return self._get_api_data(_url)['comments']
+        return self._parse_data(self._get_api_data(_url)['comments'])
